pub fn storage_buffers_are_unsupported(limits: &WgpuLimits) -> boolExpand description
Returns true if storage buffers are unsupported on this platform or false if they are supported.
pub fn storage_buffers_are_unsupported(limits: &WgpuLimits) -> boolReturns true if storage buffers are unsupported on this platform or false if they are supported.